==> audiochain-1.1.5-src.tgz: org/audiochain/ui/gui/mixer/CreateSynchronizationConnectionDialog.java <==
/**
   AudioChain Copyright (C) 2012-2013 Florian Paul (www.audiochain.org)
   
   This program is free software; you can redistribute it and/or modify it under the terms of the 
   GNU General Public License as published by the Free Software Foundation; either version 3 of the 
   License, or (at your option) any later version.
   
   This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without 
   even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General 
   Public License for more details.
   
   You should have received a copy of the GNU General Public License along with this program; 
   if not, see <http://www.gnu.org/licenses/>. 
 */
package org.audiochain.ui.gui.mixer;

import static org.audiochain.ui.gui.Dialog.*;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.IOException;
import java.net.UnknownHostException;

import javax.swing.GroupLayout;
import javax.swing.GroupLayout.Alignment;
import javax.swing.JButton;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JTextField;
import javax.swing.event.DocumentEvent;
import javax.swing.event.DocumentListener;

import org.audiochain.ui.gui.GlobalGuiContext;
import org.audiochain.ui.gui.NotificationDialog;
import org.audiochain.ui.sync.SyncManager;


public class CreateSynchronizationConnectionDialog extends NotificationDialog {
	private JPanel mainPanel;
	private JLabel remoteHostLabel;
	private JTextField remoteHostField;
	private JLabel remotePortLabel;
	private JTextField remotePortField;
	private JButton testConnectionButton;
	
	public CreateSynchronizationConnectionDialog(Object caller) {
		super(caller);
		init();
	}

	protected void init() {
		initComponents();
		initValues();
		registerListeners();
		createLayout();
		
		if (isButtonPressed(caller, "Open Remote Connection", mainPanel, applyButton)) {
			SyncManager syncManager = SyncManager.getInstance();
			String host = remoteHostField.getText();
			int port = Integer.parseInt(remotePortField.getText());
			try {
				syncManager.createRemoteConnection(host, port);
				syncManager.setLastRemoteHost(host);
				syncManager.setLastRemotePort(port);
			} catch (UnknownHostException e) {
				putNotification(remoteHostField, remoteHostLabel.getText() + " is not known: " + e.getMessage());
			} catch (IOException e) {
				putNotification(remoteHostField, "Error while connecting to '" + host + "' at port " + port + ": " + e.getMessage());
			}
		}
	}

	private void initComponents() {
		mainPanel = new JPanel();
		mainPanel.setOpaque(false);
		applyButton = new JButton("Open Connection");
		testConnectionButton = new JButton("Test Connection");
		remoteHostLabel = new JLabel("Remote Host (Hostname or IP):");
		remoteHostField = new JTextField(25);
		remoteHostField.setName("Remote Host");
		remotePortLabel = new JLabel("Remote Port:");
		remotePortField = new JTextField(5);
		remotePortField.setName("Remote Port");
	}

	private void initValues() {
		SyncManager syncManager = SyncManager.getInstance();
		remoteHostField.setText(syncManager.getLastRemoteHost());
		remotePortField.setText(String.valueOf(syncManager.getLastRemotePort()));
	}

	private void registerListeners() {
		testConnectionButton.addActionListener(new ActionListener() {
			@Override
			public void actionPerformed(ActionEvent evt) {
				putNotification(remoteHostField, null);
				String host = remoteHostField.getText();
				if (!checkRemotePortValue()) {
					return;
				}
				int port = Integer.parseInt(remotePortField.getText());
				try {
					SyncManager.testRemoteConnection(host, port);
					notificationLabel.setText("Connection to '" + host + "' at port " + port + " is successful.");
				} catch (UnknownHostException e) {
					putNotification(remoteHostField, remoteHostLabel.getText() + " is not known: " + e.getMessage());
				} catch (IOException e) {
					putNotification(remoteHostField, "Error while connecting to '" + host + "' at port " + port + ": " + e.getMessage());
				} catch (IllegalArgumentException e) {
					putNotification(remoteHostField, remoteHostLabel.getText() + " is invalid. " + e.getMessage());
				}
			}
		});
		
		remotePortField.getDocument().addDocumentListener(new DocumentListener() {
			@Override
			public void insertUpdate(DocumentEvent e) {
				checkRemotePortValue();
			}

			@Override
			public void removeUpdate(DocumentEvent e) {
				checkRemotePortValue();
			}

			@Override
			public void changedUpdate(DocumentEvent e) {
				checkRemotePortValue();
			}

		});
	}
	
	private boolean checkRemotePortValue() {
		putNotification(remotePortField, null);
		try {
			String text = remotePortField.getText();
			Integer.parseInt(text.trim());
			return true;
		} catch (NumberFormatException e) {
			putNotification(remotePortField, remotePortLabel.getText() + " must be a numeric (integral) value.");
			return false;
		}
	}
	
	private void createLayout() {
		GroupLayout layout = new GroupLayout(mainPanel);
		mainPanel.setLayout(layout);
		layout.setAutoCreateContainerGaps(true);
		layout.setAutoCreateGaps(true);
		
		layout.setHorizontalGroup(layout.createParallelGroup()
			.addComponent(notificationLabel)
			.addGroup(layout.createSequentialGroup()
				.addGroup(layout.createParallelGroup()
					.addComponent(remoteHostLabel)
					.addComponent(remotePortLabel)
				)
				.addGroup(layout.createParallelGroup()
					.addComponent(remoteHostField)
					.addComponent(remotePortField)
					.addComponent(testConnectionButton)
				)
			)
		);
		
		layout.setVerticalGroup(layout.createSequentialGroup()
			.addComponent(notificationLabel)
			.addGroup(layout.createParallelGroup(Alignment.BASELINE)
				.addComponent(remoteHostLabel)
				.addComponent(remoteHostField)
			)
			.addGroup(layout.createParallelGroup(Alignment.BASELINE)
				.addComponent(remotePortLabel)
				.addComponent(remotePortField)
			)
			.addComponent(testConnectionButton)
			// add additional gap to the dialog buttons, because the notification label causes an additional distance to the dialog title on the top
			.addGap(20)
		);
	}

	@SuppressWarnings("unused")
	public static void main(String[] args) {
		GlobalGuiContext.getGuiSettings().initializeUIManager();
		new CreateSynchronizationConnectionDialog(new Object());
		System.exit(0);
	}
}

==> audiochain-1.1.6-src.tgz: org/audiochain/ui/gui/mixer/CreateSynchronizationConnectionDialog.java <==
/**
   AudioChain Copyright (C) 2012-2013 Florian Paul (www.audiochain.org)
   
   This program is free software; you can redistribute it and/or modify it under the terms of the 
   GNU General Public License as published by the Free Software Foundation; either version 3 of the 
   License, or (at your option) any later version.
   
   This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without 
   even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General 
   Public License for more details.
   
   You should have received a copy of the GNU General Public License along with this program; 
   if not, see <http://www.gnu.org/licenses/>. 
 */
package org.audiochain.ui.gui.mixer;

import static org.audiochain.ui.gui.Dialog.isButtonPressed;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.IOException;
import java.net.UnknownHostException;

import javax.swing.GroupLayout;
import javax.swing.GroupLayout.Alignment;
import javax.swing.JButton;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JTextField;
import javax.swing.event.DocumentEvent;
import javax.swing.event.DocumentListener;

import org.audiochain.ui.gui.GuiSettings;
import org.audiochain.ui.gui.NotificationDialog;
import org.audiochain.ui.sync.SyncManager;


public class CreateSynchronizationConnectionDialog extends NotificationDialog {
	private JPanel mainPanel;
	private JLabel remoteHostLabel;
	private JTextField remoteHostField;
	private JLabel remotePortLabel;
	private JTextField remotePortField;
	private JButton testConnectionButton;
	
	public CreateSynchronizationConnectionDialog(Object caller) {
		super(caller);
		init();
	}

	protected void init() {
		initComponents();
		initValues();
		registerListeners();
		createLayout();
		
		if (isButtonPressed(caller, "Open Remote Connection", mainPanel, applyButton)) {
			SyncManager syncManager = SyncManager.getInstance();
			String host = remoteHostField.getText();
			int port = Integer.parseInt(remotePortField.getText());
			try {
				syncManager.createRemoteConnection(host, port);
				syncManager.setLastRemoteHost(host);
				syncManager.setLastRemotePort(port);
			} catch (UnknownHostException e) {
				putNotification(remoteHostField, remoteHostLabel.getText() + " is not known: " + e.getMessage());
			} catch (IOException e) {
				putNotification(remoteHostField, "Error while connecting to '" + host + "' at port " + port + ": " + e.getMessage());
			}
		}
	}

	private void initComponents() {
		mainPanel = new JPanel();
		mainPanel.setOpaque(false);
		applyButton = new JButton("Open Connection");
		testConnectionButton = new JButton("Test Connection");
		remoteHostLabel = new JLabel("Remote Host (Hostname or IP):");
		remoteHostField = new JTextField(25);
		remoteHostField.setName("Remote Host");
		remotePortLabel = new JLabel("Remote Port:");
		remotePortField = new JTextField(5);
		remotePortField.setName("Remote Port");
	}

	private void initValues() {
		SyncManager syncManager = SyncManager.getInstance();
		remoteHostField.setText(syncManager.getLastRemoteHost());
		remotePortField.setText(String.valueOf(syncManager.getLastRemotePort()));
	}

	private void registerListeners() {
		testConnectionButton.addActionListener(new ActionListener() {
			@Override
			public void actionPerformed(ActionEvent evt) {
				putNotification(remoteHostField, null);
				String host = remoteHostField.getText();
				if (!checkRemotePortValue()) {
					return;
				}
				int port = Integer.parseInt(remotePortField.getText());
				try {
					SyncManager.testRemoteConnection(host, port);
					notificationLabel.setText("Connection to '" + host + "' at port " + port + " is successful.");
				} catch (UnknownHostException e) {
					putNotification(remoteHostField, remoteHostLabel.getText() + " is not known: " + e.getMessage());
				} catch (IOException e) {
					putNotification(remoteHostField, "Error while connecting to '" + host + "' at port " + port + ": " + e.getMessage());
				} catch (IllegalArgumentException e) {
					putNotification(remoteHostField, remoteHostLabel.getText() + " is invalid. " + e.getMessage());
				}
			}
		});
		
		remotePortField.getDocument().addDocumentListener(new DocumentListener() {
			@Override
			public void insertUpdate(DocumentEvent e) {
				checkRemotePortValue();
			}

			@Override
			public void removeUpdate(DocumentEvent e) {
				checkRemotePortValue();
			}

			@Override
			public void changedUpdate(DocumentEvent e) {
				checkRemotePortValue();
			}

		});
	}
	
	private boolean checkRemotePortValue() {
		putNotification(remotePortField, null);
		try {
			String text = remotePortField.getText();
			Integer.parseInt(text.trim());
			return true;
		} catch (NumberFormatException e) {
			putNotification(remotePortField, remotePortLabel.getText() + " must be a numeric (integral) value.");
			return false;
		}
	}
	
	private void createLayout() {
		GroupLayout layout = new GroupLayout(mainPanel);
		mainPanel.setLayout(layout);
		layout.setAutoCreateContainerGaps(true);
		layout.setAutoCreateGaps(true);
		
		layout.setHorizontalGroup(layout.createParallelGroup()
			.addComponent(notificationLabel)
			.addGroup(layout.createSequentialGroup()
				.addGroup(layout.createParallelGroup()
					.addComponent(remoteHostLabel)
					.addComponent(remotePortLabel)
				)
				.addGroup(layout.createParallelGroup()
					.addComponent(remoteHostField)
					.addComponent(remotePortField)
					.addComponent(testConnectionButton)
				)
			)
		);
		
		layout.setVerticalGroup(layout.createSequentialGroup()
			.addComponent(notificationLabel)
			.addGroup(layout.createParallelGroup(Alignment.BASELINE)
				.addComponent(remoteHostLabel)
				.addComponent(remoteHostField)
			)
			.addGroup(layout.createParallelGroup(Alignment.BASELINE)
				.addComponent(remotePortLabel)
				.addComponent(remotePortField)
			)
			.addComponent(testConnectionButton)
			// add additional gap to the dialog buttons, because the notification label causes an additional distance to the dialog title on the top
			.addGap(20)
		);
	}

	@SuppressWarnings("unused")
	public static void main(String[] args) {
		GuiSettings.getInstance().initializeUIManager();
		new CreateSynchronizationConnectionDialog(new Object());
		System.exit(0);
	}
}
